import importlib.resources as pkg_resources

from localspelling.util import get_lookup_dictionaries

if __package__ is not None:
    resource_file = pkg_resources.read_text(__package__, 'gb_us.txt', encoding="utf-8")
else:
    with open("gb_us.txt", "r", encoding="utf-8") as f:
        resource_file = f.read()

lookups = get_lookup_dictionaries(resource_file)


def convert_spelling(test_text: str, target_locale: str) -> str:
    """
    Localises a string to British or American spelling, conserving case.

    Please note this function converts only spelling variants such as US "honour" vs UK "honor".
    It does not localise vocabulary such as "pavement" vs "sidewalk" or "aubergine" vs "eggplant".

    It also does not localise spellings where there is more than one correct conversion, such as US "program",
    which corresponds to both "programme" and "program" in British spelling.

    :param test_text:  The input text that you want to localise.
    :param target_locale: The alpha-2 code for the target locale. "us" or "gb".
    :return: The text localised to the target locale
    """
    if target_locale not in lookups:
        raise Exception("Unknown locale " + str(target_locale))

    regex_lookup = lookups[target_locale][0]
    dict_lookup = lookups[target_locale][1]

    output = ""
    last_index = 0
    for m in regex_lookup.finditer(test_text):
        word = m.group(0)
        lookup = word.lower()

        result = dict_lookup.get(lookup, lookup)
        if word == word.upper():
            result = result.upper()
        elif word[0] == word[0].upper():
            result = result.capitalize()

        output += test_text[last_index:m.start(0)] + result

        last_index = m.end(0)
    if last_index < len(test_text):
        output += test_text[last_index:len(test_text)]
    return output



import re


def get_regex_and_raw_word(term):
    clean_term = re.sub(r'\*', '', term)
    regex = clean_term
    if not term.startswith("*"):
        regex = r'\b' + regex
    if not term.endswith("*"):
        regex = regex + r'\b'
    return regex, clean_term


def get_lookup_dictionaries(resource_file):
    gb_to_us = {}
    us_to_gb = {}
    gb_regexes = set()
    us_regexes = set()
    for l in resource_file.split("\n"):
        gb, us = l.strip().split("\t")
        this_word_gb_regex, gb_word = get_regex_and_raw_word(gb)
        this_word_us_regex, us_word = get_regex_and_raw_word(us)
        gb_regexes.add(this_word_gb_regex)
        us_regexes.add(this_word_us_regex)
        gb_to_us[gb_word] = us_word
        us_to_gb[us_word] = gb_word

    gb_regex = re.compile("(?i)" + "|".join(gb_regexes))
    us_regex = re.compile("(?i)" + "|".join(us_regexes))

    lookups = {"us": (gb_regex, gb_to_us), "gb": (us_regex, us_to_gb)}

    return lookups



from distutils.core import setup

with open("README.md", "r") as fh:
  long_description = fh.read()

setup(
  name = 'localspelling',
  packages = ['localspelling'],
  version = '0.2',
  license='MIT', 
  description = 'Translates input between UK and US spelling',
  long_description=long_description,
  long_description_content_type="text/markdown",
  author = 'Thomas Wood',                 
  author_email = 'thomas@fastdatascience.com',      
  url = 'https://fastdatascience.com',   
  keywords = ['spelling', 'localisation', 'localization', 'uk', 'us', 'british english', 'us english'],
  install_requires=[            
          
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',   
    'Intended Audience :: Developers',   
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3',   
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
  ],
  include_package_data=True,
)
